==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/ca.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de contrast alt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de contrast alt per facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Dark theme" : "Tema fosc",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema fosc que ajuda els ulls reduint la lluminositat i la brillantor generals. Com que encara es troba en desenvolupament, agrairem que informeu de les errades que hi pugueu trobar.",
    "Dyslexia font" : "Tipus de lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és un tipus de lletra gratuït dissenyat per mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "Accessibility" : "Accessibilitat",
    "Accessibility options for nextcloud" : "Paràmetres d'accessibilitat de Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Proporciona diversos paràmetres d'accessibilitat per facilitar-vos l'ús de Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautes d'accessibilitat de continguts web",
    "our issue tracker" : "el nostre seguidor d'incidències",
    "our design team" : "el nostre equip de disseny",
    "Enable" : "Activa",
    "Dark theme (beta)" : "Tema fosc (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic és un tipus de lletra dissenyat per alleujar alguns dels problemes habituals de lectura causats per la dislèxia. El tipus de lletra fou creat per Abelardo Gonzalez, que el va publicar amb una llicència oberta.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Proporciona diverses opcions d'accessibilitat per facilitar l'ús del Nextcloud",
    "Themes" : "Temes",
    "Fonts" : "Tipus de lletra",
    "enabled" : "activat"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/ca.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Tema fosc",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema fosc que ajuda els ulls reduint la lluminositat i la brillantor generals. Com que encara es troba en desenvolupament, agrairem que informeu de les errades que hi pugueu trobar.",
    "High contrast mode" : "Mode de contrast alt",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un mode de contrast alt per facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Dyslexia font" : "Tipus de lletra per a la dislèxia",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic és un tipus de lletra gratuït dissenyat per mitigar alguns dels errors de lectura habituals causats per la dislèxia.",
    "Accessibility" : "Accessibilitat",
    "Accessibility options for nextcloud" : "Paràmetres d'accessibilitat de Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Proporciona diversos paràmetres d'accessibilitat per facilitar-vos l'ús de Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautes d'accessibilitat de continguts web",
    "our issue tracker" : "el nostre seguidor d'incidències",
    "our design team" : "el nostre equip de disseny",
    "Enable" : "Activa",
    "High contrast theme" : "Tema de contrast alt",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de contrast alt per facilitar la navegació. La qualitat visual es reduirà però s'incrementarà la claredat.",
    "Dark theme (beta)" : "Tema fosc (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic és un tipus de lletra dissenyat per alleujar alguns dels problemes habituals de lectura causats per la dislèxia. El tipus de lletra fou creat per Abelardo Gonzalez, que el va publicar amb una llicència oberta.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Proporciona diverses opcions d'accessibilitat per facilitar l'ús del Nextcloud",
    "Themes" : "Temes",
    "Fonts" : "Tipus de lletra",
    "enabled" : "activat"
},
"nplurals=2; plural=(n != 1);");
